@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2014 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -42,12 +42,13 @@
 #define MBOX_MH_DIR		2
 
 
-typedef struct
+typedef struct Mailbox Mailbox;
+struct Mailbox
 	{
 	gchar		*path;
 	gchar		*homedir_path;
 	gint		mboxtype;
-	gboolean	(*check_func)();
+	gboolean	(*check_func)(Mailbox *mbox);
 	gint		mail_count;
 	gint		new_mail_count;
 	gint		old_mail_count;
@@ -57,8 +58,7 @@ typedef struct
 	off_t		last_size;
 	gboolean	is_internal;	/* Internal mail message (ie: localmachine) */
 	gboolean	changed;
-	}
-	Mailbox;
+	};
 
 static GList	*mailbox_list;
 
@@ -324,7 +324,7 @@ check_maildir(Mailbox *mbox)
   |  But, new mail arriving (writing mailbox) sets st_mtime while reading
   |  the mailbox (mail program reading) sets st_atime.  So the test
   |  st_atime > st_mtime is testing if mbox has been read since last new mail.
-  |  Mail readers may restore st_mtime after writting status.
+  |  Mail readers may restore st_mtime after writing status.
   |  And Netscape mail does status with X-Mozilla-Status: xxxS
   |    where S is bitwise or of status flags:
   |    1: read  2: replied  4: marked  8: deleted
