@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -35,25 +35,12 @@
 #include "gkrellmd-private.h"
 #include "log-private.h"
 
+#include "../src/inet.h" // for INET6 define
+
 #if !defined(WIN32)
 	#include <syslog.h>
 #endif // !WIN32
 
-// win32 defines addrinfo but only supports getaddrinfo call on winxp or newer
-#if !defined(HAVE_GETADDRINFO) && !defined(WIN32)
-struct addrinfo
-	{
-	int		ai_flags;		/* AI_PASSIVE, AI_CANONNAME, AI_NUMERICHOST */
-	int		ai_family;		/* PF_xxx */
-	int		ai_socktype;	/* SOCK_xxx */
-	int		ai_protocol;	/* 0 or IPPROTO_xxx for IPv4 and IPv6 */
-	size_t	ai_addrlen;		/* length of ai_addr */
-	char	*ai_canonname;	/* canonical name for hostname */
-	struct	sockaddr *ai_addr;	/* binary address */
-	struct	addrinfo *ai_next;	/* next structure in linked list */
-	};
-#endif // !HAVE_GETADDRINFO
-
 #if !defined(IPV6_V6ONLY) && defined(IPV6_BINDV6ONLY)
 #define	IPV6_V6ONLY	IPV6_BINDV6ONLY
 #endif
@@ -116,7 +103,7 @@ static HANDLE h_event_log = NULL;
 
 
 static gboolean
-gkrellmd_syslog_init()
+gkrellmd_syslog_init(void)
 	{
 #if defined(WIN32)
 	h_event_log = RegisterEventSourceW(NULL, service_name);
@@ -132,7 +119,7 @@ gkrellmd_syslog_init()
 	}
 
 static gboolean
-gkrellmd_syslog_cleanup()
+gkrellmd_syslog_cleanup(void)
 	{
 #if defined(WIN32)
 	if (h_event_log)
@@ -177,19 +164,19 @@ static void gkrellmd_syslog_log(GLogLevelFlags log_level, const gchar *message)
 	int facility_priority;
 
 	// default to info and override with other states if they are more important
-	facility_priority = LOG_MAKEPRI(LOG_DAEMON, LOG_INFO);
+	facility_priority = (LOG_DAEMON | LOG_INFO);
 	if (log_level & G_LOG_LEVEL_DEBUG)
-		facility_priority = LOG_MAKEPRI(LOG_DAEMON, LOG_DEBUG);
+		facility_priority = (LOG_DAEMON | LOG_DEBUG);
 	if (log_level & G_LOG_LEVEL_WARNING)
-		facility_priority = LOG_MAKEPRI(LOG_DAEMON, LOG_WARNING);
+		facility_priority = (LOG_DAEMON | LOG_WARNING);
 	if (log_level & G_LOG_LEVEL_ERROR)
-		facility_priority = LOG_MAKEPRI(LOG_DAEMON, LOG_ERR);
+		facility_priority = (LOG_DAEMON | LOG_ERR);
 	if (log_level & G_LOG_LEVEL_CRITICAL)
-		facility_priority = LOG_MAKEPRI(LOG_DAEMON, LOG_CRIT);
+		facility_priority = (LOG_DAEMON | LOG_CRIT);
 
 	syslog(facility_priority, "%s", message);
 #endif // defined(WIN32)
-	} // gkrellmd_syslog_log()
+	}
 
 
 static void
@@ -221,7 +208,7 @@ remove_pidfile(void)
 	}
 
 static void
-gkrellmd_cleanup()
+gkrellmd_cleanup(void)
 	{
 	gkrellm_sys_main_cleanup();
 	gkrellm_log_cleanup();
@@ -231,9 +218,9 @@ gkrellmd_cleanup()
 static void
 cb_sigterm(gint sig)
 	{
-	g_message("GKrellM Daemon %d.%d.%d%s: Exiting normally\n",
+	g_message("GKrellM Daemon %d.%d.%d: Exiting normally\n",
 			GKRELLMD_VERSION_MAJOR, GKRELLMD_VERSION_MINOR,
-			GKRELLMD_VERSION_REV, GKRELLMD_EXTRAVERSION);
+			GKRELLMD_VERSION_REV);
 	gkrellmd_cleanup();
 	exit(0);
 	}
@@ -259,38 +246,6 @@ gkrellmd_send_to_client(GkrellmdClient *client, gchar *buf)
 	return n;
 	}
 
-#if 0
-static gint
-getline(gint fd, gchar *buf, gint len)
-	{
-	fd_set			read_fds;
-	struct timeval	tv;
-	gchar			*s;
-	gint			result, n;
-
-	FD_ZERO(&read_fds);
-	FD_SET(fd, &read_fds);
-	tv.tv_usec = 0;
-	tv.tv_sec = 15;
-	s = buf;
-	*s = '\0';
-	for (n = 0; n < len - 1; ++n)
-		{
-		result = select(fd + 1, &read_fds, NULL, NULL, &tv);
-		if (result <= 0 || read(fd, s, 1) != 1)
-			break;
-		if (*s == '\n')
-			{
-			*s = '\0';
-			break;
-			}
-		*++s = '\0';
-		}
-	return n;
-	}
-#endif
-
-#ifdef HAVE_GETADDRINFO
 static gboolean
 is_valid_reverse(char *addr, char *host, sa_family_t family)
 	{
@@ -331,14 +286,12 @@ is_valid_reverse(char *addr, char *host, sa_family_t family)
 	freeaddrinfo(res);
 	return good;
 	}
-#endif
 
 /* Check for CIDR match.
  */
 static gboolean
 cidr_match(struct sockaddr *sa, socklen_t salen, char *allowed)
 {
-#ifdef HAVE_GETADDRINFO
 	struct addrinfo hints, *res;
 	union {
 	    struct sockaddr_storage	ss;
@@ -433,27 +386,19 @@ cidr_match(struct sockaddr *sa, socklen_t salen, char *allowed)
 			return FALSE;
 		}
 	return TRUE;
-#else
-	return FALSE;
-#endif
 }
 
 static gboolean
 allow_host(GkrellmdClient *client, struct sockaddr *sa, socklen_t salen)
 	{
 	GList			*list;
-#ifdef HAVE_GETADDRINFO
 	int error;
 	char hostbuf[NI_MAXHOST], addrbuf[NI_MAXHOST];
-#else
-	struct hostent	*hostent;
-#endif
 	gchar			buf[128];
 	gchar			*hostname = NULL,
 					*addr = NULL;
 	gchar			*s, *allowed;
 
-#ifdef HAVE_GETADDRINFO
 	error = getnameinfo(sa, salen, addrbuf, sizeof(addrbuf),
 			    NULL, 0, NI_NUMERICHOST | NI_WITHSCOPEID);
 	if (error == 0)
@@ -465,30 +410,44 @@ allow_host(GkrellmdClient *client, struct sockaddr *sa, socklen_t salen)
 		    is_valid_reverse(addrbuf, hostbuf, sa->sa_family))
 			hostname = hostbuf;
 		}
-#else
-	hostent = gethostbyaddr((gchar *)&((struct sockaddr_in *)sa)->sin_addr,
-				sizeof(struct in_addr), AF_INET);
-	if (hostent)
-		hostname = hostent->h_name;
-	addr = inet_ntoa(((struct sockaddr_in *)sa)->sin_addr);
-#endif
+
+	gkrellm_debug(DEBUG_SERVER, "Connect from %s[%s]\n", hostname ? hostname : "[unknown]", addr);
 
 	client->hostname = g_strdup(hostname ? hostname : addr);
 
 	if (!allow_host_list)
+		{
+		gkrellm_debug(DEBUG_SERVER, "Client %s[%s] allowed, no allowed hosts list\n", (hostname ? hostname : "[unknown]"), addr);
 		return TRUE;
+		}
 
 	for (list = allow_host_list; list; list = list->next)
 		{
 		allowed = (gchar *) list->data;
-		if (   (hostname && !strcmp(hostname, allowed))
-			|| (addr && !strcmp(addr, allowed))
-			|| !strcmp("ALL", allowed)
-		   )
+
+		if (!strcmp("ALL", allowed))
+			{
+			gkrellm_debug(DEBUG_SERVER, "Client %s[%s] matches ALL\n", (hostname ? hostname : "[unknown]"), addr);
 			return TRUE;
+			}
+
+		if (hostname && !strcmp(hostname, allowed))
+			{
+			gkrellm_debug(DEBUG_SERVER, "Client %s[%s] matches hostname %s\n", (hostname ? hostname : "[unknown]"), addr, allowed);
+			return TRUE;
+			}
+
+		if (addr && !strcmp(addr, allowed))
+			{
+			gkrellm_debug(DEBUG_SERVER, "Client %s[%s] matches address %s\n", (hostname ? hostname : "[unknown]"), addr, allowed);
+			return TRUE;
+			}
 
 		if (addr && cidr_match(sa, salen, allowed))
+			{
+			gkrellm_debug(DEBUG_SERVER, "Client %s[%s] matches CIDR address %s\n", (hostname ? hostname : "[unknown]"), addr, allowed);
 			return TRUE;
+			}
 
 		/* Check for simple IPv4 subnet match.  Worry later about ranges and
 		|  other hosts_access type patterns.
@@ -498,7 +457,12 @@ allow_host(GkrellmdClient *client, struct sockaddr *sa, socklen_t salen)
 			&& *(s + 1) == '*' && *(s + 2) == '\0'
 			&& !strncmp(addr, allowed, (gint) (s - allowed + 1))
 		   )
-				return TRUE;
+			{
+			gkrellm_debug(DEBUG_SERVER, "Client %s[%s] matches IPv4 wildcard %s\n", (hostname ? hostname : "[unknown]"), addr, allowed);
+			return TRUE;
+			}
+
+		gkrellm_debug(DEBUG_SERVER, "Client %s[%s] not matched by %s\n", (hostname ? hostname : "[unknown]"), addr, allowed);
 		}
 
 	snprintf(buf, sizeof(buf), _("Connection not allowed from %s\n"),
@@ -541,7 +505,6 @@ accept_client(gint fd, struct sockaddr *sa, socklen_t salen)
 		buf[err] = '\0';
 	else
 		buf[0] = '\0';
-	//getline(fd, buf, sizeof(buf));
 
 	if (_GK.verbose)
 		g_print(_("connect string from client: %s\n"), buf);
@@ -687,8 +650,6 @@ load_config(gchar *path)
 	gchar			buf[128+32+2], config[32], arg[128];
 	gchar			*s, *plugin_config_block = NULL;
 
-	//g_print("Trying to load config from file '%s'\n", path);
-
 	f = g_fopen(path, "r");
 	if (!f)
 		return;
@@ -769,6 +730,8 @@ read_config(void)
 	_GK.debug_level = 0;
 	_GK.max_clients = 2;
 	_GK.server_port = GKRELLMD_SERVER_PORT;
+	_GK.io_timeout = 30;
+	_GK.reconnect_timeout = 60;
 
 	_GK.fs_interval = 2;
 	_GK.nfs_interval = 16;
@@ -908,7 +871,7 @@ get_args(gint argc, gchar **argv)
 			usage();
 			exit(0);
 			}
-		} // for()
+		}
 	}
 
 
@@ -917,16 +880,11 @@ socksetup(int af)
 	{
 	struct addrinfo	hints, *res, *r;
 	gint			maxs, *s, *socks;
-#ifndef HAVE_GETADDRINFO
-	struct sockaddr_in	sin;
-#else
 	gchar			portnumber[6];
 	gint			error;
-#endif
 
 	memset(&hints, 0, sizeof(hints));
 	hints.ai_socktype = SOCK_STREAM;
-#ifdef HAVE_GETADDRINFO
 	hints.ai_flags = AI_PASSIVE;
 	hints.ai_family = af;
 	snprintf(portnumber, sizeof(portnumber), "%d", _GK.server_port);
@@ -943,26 +901,6 @@ socksetup(int af)
 		g_warning("gkrellmd %s\n", gai_strerror(error));
 		return NULL;
 		}
-#else
-	/* Set up the address structure for the listen socket and bind the
-	|  listen address to the socket.
-	*/
-	hints.ai_family = PF_INET;
-	hints.ai_addrlen = sizeof(struct sockaddr_in);
-	hints.ai_next = NULL;
-	hints.ai_addr = (struct sockaddr *) &sin;
-	sin.sin_family = PF_INET;
-	if (!_GK.server_address || strlen(_GK.server_address) == 0)
-		{
-		sin.sin_addr.s_addr = INADDR_ANY;
-		}
-	else
-		{
-		sin.sin_addr.s_addr = inet_addr(_GK.server_address);
-		}
-	sin.sin_port = htons(_GK.server_port);
-	res = &hints;
-#endif
 
 	/* count max number of sockets we may open */
 	for (maxs = 0, r = res; r; r = r->ai_next, maxs++)
@@ -1013,8 +951,11 @@ socksetup(int af)
 #ifdef IPV6_V6ONLY
 		if (r->ai_family == AF_INET6)
 			{
+#if defined(WIN32)
+			const char on = 1;
+#else
 			const int on = 1;
-
+#endif
 			if (setsockopt(*s, IPPROTO_IPV6, IPV6_V6ONLY, &on, sizeof(on)) < 0)
 				{
 				g_warning("gkrellmd: setsockopt (IPV6_V6ONLY) failed\n");
@@ -1040,10 +981,8 @@ socksetup(int af)
 		s++;
 	}
 
-#ifdef HAVE_GETADDRINFO
 	if (res)
 		freeaddrinfo(res);
-#endif
 
 	if (*socks == 0)
 		{
@@ -1153,11 +1092,7 @@ static gint
 gkrellmd_run(gint argc, gchar **argv)
 	{
     union {
-#ifdef HAVE_GETADDRINFO
 	struct sockaddr_storage ss;
-#else
-	struct sockaddr_in	ss;
-#endif
 	struct sockaddr_in	sin;
 	struct sockaddr	sa;
     } client_addr;
@@ -1179,9 +1114,8 @@ gkrellmd_run(gint argc, gchar **argv)
 	get_args(argc, argv);
 
 	// first message that might get logged
-	g_message("Starting GKrellM Daemon %d.%d.%d%s\n", GKRELLMD_VERSION_MAJOR,
-			GKRELLMD_VERSION_MINOR, GKRELLMD_VERSION_REV,
-			GKRELLMD_EXTRAVERSION);
+	g_message("Starting GKrellM Daemon %d.%d.%d\n", GKRELLMD_VERSION_MAJOR,
+			GKRELLMD_VERSION_MINOR, GKRELLMD_VERSION_REV);
 
 	if (_GK.verbose)
 		g_print("update_HZ=%d\n", _GK.update_HZ);
@@ -1366,9 +1300,9 @@ gkrellmd_run(gint argc, gchar **argv)
 				}
 			}
 		gkrellmd_update_monitors();
-		} // while(1)
+		}
 	return 0;
-	} // gkrellmd_main()
+	}
 
 
 #if defined(WIN32)
@@ -1433,9 +1367,9 @@ void WINAPI service_main(DWORD argc, WCHAR* argv[])
 
 		// services are not stopped via process signals so we have to
 		// clean up like in cb_sigterm() but without calling exit()!
-		g_message("GKrellM Daemon %d.%d.%d%s: Exiting normally\n",
+		g_message("GKrellM Daemon %d.%d.%d: Exiting normally\n",
 				GKRELLMD_VERSION_MAJOR, GKRELLMD_VERSION_MINOR,
-				GKRELLMD_VERSION_REV, GKRELLMD_EXTRAVERSION);
+				GKRELLMD_VERSION_REV);
 		gkrellmd_cleanup();
 
 		// free all strings in pointer array and free the array itself
@@ -1451,7 +1385,7 @@ void WINAPI service_main(DWORD argc, WCHAR* argv[])
 		}
 	}
 
-void service_run()
+void service_run(void)
 	{
 	SERVICE_TABLE_ENTRYW service_table[] =
 		{ {service_name, service_main}, { 0, 0 } };
@@ -1533,7 +1467,7 @@ static gboolean service_stop(SC_HANDLE serviceHandle)
 	}
 
 
-static gboolean service_install()
+static gboolean service_install(void)
 	{
 	WCHAR path[_MAX_PATH + 1];
 	SC_HANDLE scmHandle;
@@ -1599,7 +1533,7 @@ static gboolean service_install()
 	} /* service_install() */
 
 
-static gboolean service_uninstall()
+static gboolean service_uninstall(void)
 	{
 	SC_HANDLE scmHandle;
 	SC_HANDLE svcHandle;
@@ -1715,9 +1649,8 @@ int main(int argc, char* argv[])
 			}
 		else if (!strcmp(opt, "version") || !strcmp(opt, "v"))
 			{
-			g_print("gkrellmd %d.%d.%d%s\n", GKRELLMD_VERSION_MAJOR,
-					GKRELLMD_VERSION_MINOR, GKRELLMD_VERSION_REV,
-					GKRELLMD_EXTRAVERSION);
+			g_print("gkrellmd %d.%d.%d\n", GKRELLMD_VERSION_MAJOR,
+					GKRELLMD_VERSION_MINOR, GKRELLMD_VERSION_REV);
 			return 0;
 			}
 #if defined(WIN32)
