@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -69,11 +69,11 @@ any(gchar c, gchar *s)
   |  found token.  If there is no next token, return an empty dupped string
   |  (not a NULL pointer) and leave *string unchanged.
   |  Unlike strtok(): args are not modified, gkrellm_token() can be used on
-  |  constant strings, delimeter identity is not lost, and it's thread safe.
+  |  constant strings, delimiter identity is not lost, and it's thread safe.
   |  Only the caller's initial string pointer is modified.
   */
 gchar *
-gkrellmd_dup_token(gchar **string, gchar *delimeters)
+gkrellmd_dup_token(gchar **string, gchar *delimiters)
 	{
 	gchar			*str, *s, *delims;
 	gboolean		quoted = FALSE;
@@ -82,7 +82,7 @@ gkrellmd_dup_token(gchar **string, gchar *delimeters)
 		return g_strdup("");
 
 	str = *string;
-	delims = delimeters ? delimeters : " \t\n";
+	delims = delimiters ? delimiters : " \t\n";
 	while (any(*str, delims))
 		++str;
 
@@ -102,9 +102,9 @@ gkrellmd_dup_token(gchar **string, gchar *delimeters)
 	}
 
 gchar *
-gkrellm_dup_token(gchar **string, gchar *delimeters)
+gkrellm_dup_token(gchar **string, gchar *delimiters)
 	{
-	return gkrellmd_dup_token(string, delimeters);
+	return gkrellmd_dup_token(string, delimiters);
 	}
 
 void
