@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -765,7 +765,7 @@ gkrellm_alert_plugin_add(GkrellmMonitor *mon, gchar *name)
 void
 gkrellm_alert_plugin_alert_connect(GkrellmAlertPlugin *gap,
 			void (*alarm_func)(), void (*warn_func)(),
-			void (*update_func)(), void (*check_func)(),
+			void (*update_func)(), void (*check_func)(GkrellmAlert* alert, gpointer data, gfloat value),
 			void (*destroy_func)())
 	{
 	gap->alarm_func = alarm_func;
@@ -777,8 +777,10 @@ gkrellm_alert_plugin_alert_connect(GkrellmAlertPlugin *gap,
 
 void
 gkrellm_alert_plugin_config_connect(GkrellmAlertPlugin *gap, gchar *tab_name,
-			void (*config_create_func)(), void (*config_apply_func),
-			void (*config_save_func)(), void (*config_load_func)())
+			void (*config_create_func)(),
+			void (*config_apply_func)(),
+			void (*config_save_func)(),
+			void (*config_load_func)())
 	{
 	if (!gap)
 		return;
@@ -1159,7 +1161,7 @@ gkrellm_alert_config_window(GkrellmAlert **ap)
 	if (!alert->config_window)
 		{
 		alert->config_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-		g_signal_connect(G_OBJECT(alert->config_window), "delete_event",
+		g_signal_connect(G_OBJECT(alert->config_window), "delete-event",
 				G_CALLBACK(alert_config_window_delete_event), ap);
 		gtk_window_set_title(GTK_WINDOW(alert->config_window),
 				_("GKrellM Set Alerts"));
@@ -1349,26 +1351,26 @@ gkrellm_alert_config_window(GkrellmAlert **ap)
 		gtk_box_pack_end(GTK_BOX(hbox1), hbox, FALSE, FALSE, 0);
 
 		alert->delete_button = gtk_button_new_from_stock(GTK_STOCK_DELETE);
-		GTK_WIDGET_SET_FLAGS(alert->delete_button, GTK_CAN_DEFAULT);
+		gtk_widget_set_can_default(alert->delete_button, 1);
 		g_signal_connect(G_OBJECT(alert->delete_button), "clicked",
 				G_CALLBACK(alert_delete), ap);
 		gtk_box_pack_start(GTK_BOX(hbox), alert->delete_button, TRUE, TRUE, 0);
 		gtk_widget_set_sensitive(alert->delete_button, alert->activated);
 
 		button = gtk_button_new_from_stock(GTK_STOCK_APPLY);
-		GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+		gtk_widget_set_can_default(button, 1);
 		g_signal_connect(G_OBJECT(button), "clicked",
 				G_CALLBACK(alert_apply), ap);
 		gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
 
 		button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
-		GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+		gtk_widget_set_can_default(button, 1);
 		g_signal_connect(G_OBJECT(button), "clicked",
 				G_CALLBACK(alert_close), ap);
 		gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
 
 		button = gtk_button_new_from_stock(GTK_STOCK_OK);
-		GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+		gtk_widget_set_can_default(button, 1);
 		g_signal_connect(G_OBJECT(button), "clicked",
 				G_CALLBACK(alert_ok), ap);
 		gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
@@ -1624,7 +1626,7 @@ gkrellm_alert_pixbuf(void)
 		width  = big_endian_uint(data + 16);
 		height = big_endian_uint(data + 20);
 
-		pixels = g_memdup((gconstpointer)(data + 24), height * stride);
+		pixels = g_memdup2((gconstpointer)(data + 24), height * stride);
 
 		alert_pixbuf = gdk_pixbuf_new_from_data(pixels,
 				GDK_COLORSPACE_RGB, TRUE, 8, width, height, stride,
