@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -53,44 +53,18 @@
 #include <errno.h>
 
 
-
-#if defined(__linux__)
-#define HAVE_GETADDRINFO	1
-#endif
-
-#if defined(__DragonFly__)
-#define HAVE_GETADDRINFO	1
-#endif
-
-#if defined(__FreeBSD__)
-#if __FreeBSD_version >= 400000
-#define HAVE_GETADDRINFO	1
-#endif
-#endif
-
-#if defined(__OpenBSD__)
-#define HAVE_GETADDRINFO	1
-#endif
-
-#if defined(__NetBSD__)
-#define HAVE_GETADDRINFO	1
-#endif
-
 #if defined(__solaris__)
 /* getaddrinfo is related to IPv6 stuff */
 # include <netconfig.h>
-# if defined(NC_INET6)
-#  define HAVE_GETADDRINFO	1
-# endif
 #endif
 
-
 typedef struct
 	{
-	gchar	*key;
-	void	(*func)();
+	const gchar *key;
+	GkrellmClientDataFunc func;
 	}
-	KeyTable;
+	ClientUpdateTable;
+
 
 static gint		server_major_version,
 				server_minor_version,
@@ -382,7 +356,7 @@ read_disk_data(void)
 	}
 
 static gint
-order_from_name(gchar *name)
+order_from_name(const gchar *name)
 	{
 	return -1;
 	}
@@ -573,15 +547,51 @@ static GList	*inet_list;
 
 static gboolean	inet_unsupported;
 
+static gboolean
+client_inet_parse_numeric_host(const char *name, int family, ActiveTCP *tcp)
+{
+	struct addrinfo	hints;
+	memset(&hints, 0, sizeof(hints));
+	hints.ai_family = family;
+	hints.ai_socktype = SOCK_STREAM;
+	hints.ai_flags = AI_PASSIVE | AI_NUMERICHOST;
+
+	struct addrinfo *res = NULL;
+	if (getaddrinfo(name, NULL, &hints, &res) != 0)
+		{
+		return FALSE;
+		}
+
+	g_assert(res->ai_family == family);
+	tcp->family = family;
+
+	if (family == AF_INET)
+		{
+		memcpy(&tcp->remote_addr,
+					&((struct sockaddr_in *)res->ai_addr)->sin_addr,
+					sizeof(struct in_addr));
+		}
+#if defined(INET6)
+	else if (family == AF_INET6)
+		{
+		memcpy(&tcp->remote_addr6,
+					&((struct sockaddr_in6 *)res->ai_addr)->sin6_addr,
+					sizeof(struct in6_addr));
+		}
+#endif
+
+	freeaddrinfo(res);
+	return TRUE;
+}
+
 static void
 client_inet_line_from_server(gchar *line)
 	{
 	GList		*list;
 	ActiveTCP	tcp, *t;
 	gchar		*ap, *aap;
-#if defined(INET6) && defined(HAVE_GETADDRINFO)
-	struct addrinfo	hints, *res;
-	gchar		buf[NI_MAXHOST];
+#if defined(INET6)
+	gchar		buf[NI_MAXHOST+1];
 #else
 	gchar		buf[128];
 #endif
@@ -593,30 +603,20 @@ client_inet_line_from_server(gchar *line)
 		{
 		n = sscanf(line + 3, "%x %127[^:]:%x", &tcp.local_port,
 			   buf, &tcp.remote_port);
-		if (n != 3 || inet_aton(buf, &tcp.remote_addr) == 0)
+		if (n != 3 || !client_inet_parse_numeric_host(buf, AF_INET, &tcp))
+			{
 			return;
-		tcp.family = AF_INET;
+			}
 		}
-#if defined(INET6) && defined(HAVE_GETADDRINFO)
+#if defined(INET6)
 	else if (*(line + 1) == '6')
 		{
-#define STR(x)	#x
-#define XSTR(x)	STR(x)
-		n = sscanf(line + 3, "%x [%" XSTR(NI_MAXHOST) "[^]]]:%x",
+		n = sscanf(line + 3, "%x [%" G_STRINGIFY(NI_MAXHOST) "[^]]]:%x",
 			   &tcp.local_port, buf, &tcp.remote_port);
-		if (n != 3)
+		if (n != 3 || !client_inet_parse_numeric_host(buf, AF_INET6, &tcp))
+			{
 			return;
-		memset(&hints, 0, sizeof(hints));
-		hints.ai_family = AF_INET6;
-		hints.ai_socktype = SOCK_STREAM;
-		hints.ai_flags = AI_PASSIVE | AI_NUMERICHOST;
-		if (getaddrinfo(buf, NULL, &hints, &res) != 0)
-			return;
-		memcpy(&tcp.remote_addr6,
-		       &((struct sockaddr_in6 *)res->ai_addr)->sin6_addr,
-		       sizeof(struct in6_addr));
-		freeaddrinfo(res);
-		tcp.family = AF_INET6;
+			}
 		}
 #endif
 	if (*line == '+')
@@ -1327,7 +1327,16 @@ client_sysname_setup(gchar *s)
 	}
 
 
-KeyTable	monitor_table[] =
+typedef void (*MonitorInitFunc)(void);
+
+typedef struct
+	{
+	const gchar* key;
+	MonitorInitFunc func;
+	}
+	MonitorInitTable;
+
+static MonitorInitTable	monitor_table[] =
 	{
 	{"sensors",		client_sys_sensors_init },
 	{"cpu",			client_sys_cpu_init },
@@ -1363,7 +1372,7 @@ client_plugin_add_setup_line(gchar *line)
   */
 void
 gkrellm_client_plugin_get_setup(gchar *key_name,
-				void (*setup_func_cb)(gchar *str))
+				GkrellmClientDataFunc setup_func_cb)
 	{
 	GList	*list;
 	gchar	*line, *s;
@@ -1388,14 +1397,14 @@ gkrellm_client_plugin_get_setup(gchar *key_name,
 static void
 client_monitor_setup(gchar *line)
 	{
-	void			(*func)();
+	MonitorInitFunc func;
 	gchar			buf[64];
 	gint			i;
 	gboolean		found_builtin = FALSE;
 
 	if (!*line || setup_done)
 		return;
-	for (i = 0; i < sizeof(monitor_table) / sizeof(KeyTable); ++i)
+	for (i = 0; i < sizeof(monitor_table) / sizeof(MonitorInitTable); ++i)
 		{
 		if (!strcmp(line, monitor_table[i].key))
 			{
@@ -1405,7 +1414,7 @@ client_monitor_setup(gchar *line)
 			break;
 			}
 		}
-	/* The client mode init work of a plugin must be defered since they
+	/* The client mode init work of a plugin must be deferred since they
 	|  aren't loaded yet.  Set up so they will can get an "available" flag.
 	*/
 	if (!found_builtin)
@@ -1471,7 +1480,8 @@ client_server_reconnect_timeout(gchar *line)
 
 
 /* ================================================================= */
-KeyTable	setup_table[] =
+
+static ClientUpdateTable setup_table[] =
 	{
 	{"<version>",		client_server_version_setup },
 	{"<sensors_setup>",	client_sensors_setup },
@@ -1500,19 +1510,19 @@ typedef struct
 	{
 	GkrellmMonitor	*mon;
 	gchar			*key_name;
-	void			(*func_cb)(gchar *line);
+	GkrellmClientDataFunc func_cb;
 	}
 	ClientPlugin;
 
 static GList	*client_plugin_serve_data_list;
 static GList	*plugin_initial_update_list;
 
-static GkrellmFunc
+static GkrellmClientDataFunc
 client_plugin_func(gchar *line)
 	{
 	GList			*list;
 	ClientPlugin	*plug;
-	void			(*func)() = NULL;
+	GkrellmClientDataFunc func = NULL;
 	gchar			*s;
 	gint			n;
 
@@ -1619,7 +1629,7 @@ gkrellm_client_send_to_server(gchar *key_name, gchar *line)
 	return result;
 	}
 
-KeyTable	update_table[] =
+static ClientUpdateTable update_table[] =
 	{
 	{"<cpu>",			client_cpu_line_from_server},
 	{"<proc>",			client_proc_line_from_server},
@@ -1683,9 +1693,9 @@ gkrellm_getline(gint fd, gchar *buf, gint len)
 	}
 
 static void
-process_server_line(KeyTable *table, gint table_size, gchar *line)
+process_server_line(const ClientUpdateTable *table, gint table_size, gchar *line)
 	{
-	static void		(*func)(gchar *);
+	static GkrellmClientDataFunc func;
 	gint			i;
 
 	if (!*line || *line == '#')
@@ -1736,7 +1746,7 @@ read_server_setup(gint fd)
 	*/
 	locale_sync();
 	_GK.client_server_read_time = time(0);
-	table_size = sizeof(setup_table) / sizeof(KeyTable);
+	table_size = sizeof(setup_table) / sizeof(ClientUpdateTable);
 
 	gkrellm_free_glist_and_data(&client_plugin_setup_line_list);
 
@@ -1748,7 +1758,7 @@ read_server_setup(gint fd)
 		if (rs == 0)
 			{
 			if (--retries)
-				usleep(10000);
+				g_usleep(10000);
 			else
 				return FALSE;
 			}
@@ -1764,7 +1774,7 @@ read_server_setup(gint fd)
 
 	/* Read the initial update data
 	*/
-	table_size = sizeof(update_table) / sizeof(KeyTable);
+	table_size = sizeof(update_table) / sizeof(ClientUpdateTable);
 	while (1)
 		{
 		rs = gkrellm_getline(fd, buf, sizeof(buf));
@@ -1772,7 +1782,7 @@ read_server_setup(gint fd)
             return FALSE;
         if (rs==0){
         	if(--retries)
-        		usleep(10000);
+				g_usleep(10000);
         	else
         		return FALSE;
         }
@@ -1821,7 +1831,7 @@ read_server_input(gpointer data, gint fd, GdkInputCondition condition)
 		_GK.client_server_read_time = _GK.time_now;
 	server_buf[buf_index + count] = '\0';
 	line = server_buf;
-	table_size = sizeof(update_table) / sizeof(KeyTable);
+	table_size = sizeof(update_table) / sizeof(ClientUpdateTable);
 	while (*line && (eol = strchr(line, '\n')) != NULL)
 		{
 		*eol = '\0';
@@ -1851,16 +1861,10 @@ gint
 gkrellm_connect_to(gchar *server, gint server_port)
 	{
 	gint		fd	= -1;
-#ifdef HAVE_GETADDRINFO
 	gint 		rv	= 0;
 	struct addrinfo	hints, *res, *res0;
 	gchar		portnumber[6];
-#else
-	struct hostent	*addr;
-	struct sockaddr_in s;
-#endif
 
-#ifdef HAVE_GETADDRINFO
 	snprintf (portnumber, sizeof(portnumber), "%d", server_port);
 	memset(&hints, 0, sizeof(hints));
 	hints.ai_family = PF_UNSPEC;
@@ -1887,36 +1891,6 @@ gkrellm_connect_to(gchar *server, gint server_port)
 		fd = -1;
 		}
 	freeaddrinfo(res0);
-#else
-	gkrellm_debug(DEBUG_CLIENT, "\t[gkrellm_connect_to: %s:%d]\n", server,
-		server_port);
-	addr = gethostbyname(server);
-	if (addr)
-		{
-		fd = socket(AF_INET, SOCK_STREAM, 0);
-		if (fd >= 0)
-			{
-			memset(&s, 0, sizeof(s));
-			memcpy(&s.sin_addr.s_addr, addr->h_addr, addr->h_length);
-			s.sin_family = AF_INET;
-			s.sin_port = htons(server_port);
-			if (connect(fd, (struct sockaddr *)&s, sizeof (s)) < 0)
-				{
-				gkrellm_debug(DEBUG_CLIENT, "gkrellm_connect_to(); connect() failed\n");
-#ifdef WIN32
-				closesocket(fd);
-#else
-				close(fd);
-#endif
-				fd = -1;
-				}
-			}
-		}
-	else
-		{
-		gkrellm_debug(DEBUG_CLIENT, "gkrellm_connect_to(); gethostbyname() failed\n");
-		}
-#endif
 	if (fd < 0)
 		return -1;
 
@@ -1935,9 +1909,9 @@ gkrellm_client_mode_connect(void)
 	if (client_fd < 0)
 		return BAD_CONNECT;
 
-	snprintf(buf, sizeof(buf), "gkrellm %d.%d.%d%s\n",
+	snprintf(buf, sizeof(buf), "gkrellm %d.%d.%d\n",
 			GKRELLM_VERSION_MAJOR, GKRELLM_VERSION_MINOR,
-			GKRELLM_VERSION_REV, GKRELLM_EXTRAVERSION);
+			GKRELLM_VERSION_REV);
 	send(client_fd, buf, strlen(buf), 0);
 
 	/* Initial setup lines from server are read in blocking mode.
