@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -59,8 +59,6 @@
 
 #include	"pixmaps/decal_alarm.xpm"
 #include	"pixmaps/decal_warn.xpm"
-//#include	"pixmaps/krell_alarm.xpm"
-//#include	"pixmaps/krell_warn.xpm"
 
   /* These data images are used only for the default theme
   */
@@ -151,7 +149,7 @@ gkrellm_theme_file_exists(char *name, gchar *subdir)
 	{
 	gint			i;
 	static gchar	*path;
-	struct stat		st;
+	GStatBuf		st;
 
 	if (gkrellm_using_default_theme())
 		return NULL;
@@ -567,8 +565,6 @@ assign_custom_style(gchar *debug_name, GList *style_list, gint index,
 		custom_style =
 				(GkrellmStyle *) g_list_nth_data(_GK.custom_style_list, i);
 
-//g_debug("assign_custom_style(%s, %s, %d, %s) %d\n",
-//debug_name, custom_name, entry_flag, arg, i);
 	assign_style_entry(custom_style, arg, entry_flag);
 	set_themed(custom_style, entry_flag);
 	}
@@ -784,14 +780,13 @@ setup_piximages(void)
 	if (_GK.frame_left_width == 0)
 		_GK.frame_left_width =
 				gdk_pixbuf_get_width(_GK.frame_left_piximage->pixbuf);
-//	_GK.frame_left_width =	_GK.frame_left_width * _GK.theme_scale / 100;
+
 	gkrellm_set_piximage_border(_GK.frame_left_piximage,
 						&_GK.frame_left_border);
 
 	if (_GK.frame_right_width == 0)
 		_GK.frame_right_width =
 				gdk_pixbuf_get_width(_GK.frame_right_piximage->pixbuf);
-//	_GK.frame_right_width = _GK.frame_right_width * _GK.theme_scale / 100;
 
 	gkrellm_set_piximage_border(_GK.frame_right_piximage,
 						&_GK.frame_right_border);
