@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -50,7 +50,8 @@ static void	cb_alert_config_create(GkrellmAlert *ap, GtkWidget *vbox,
 #endif
 
 
-typedef struct
+typedef struct CpuMon CpuMon;
+struct CpuMon
 	{
 	gchar			*name;
 	gchar			*panel_label;
@@ -87,8 +88,7 @@ typedef struct
 					nice,
 					sys,
 					idle;
-	}
-	CpuMon;
+	};
 
 
 static GkrellmMonitor
@@ -97,7 +97,7 @@ static GkrellmMonitor
 GList			*cpu_mon_list,
 				*instance_list;
 
-void			(*read_cpu_data)();
+static GkrellmCpuReadFunc read_cpu_data;
 static CpuMon	*composite_cpu;
 
 static GkrellmAlert	*cpu_alert;		/* One alert duped for each CPU */
@@ -138,7 +138,7 @@ setup_cpu_interface(void)
 	}
 
 void
-gkrellm_cpu_client_divert(void (*read_func)())
+gkrellm_cpu_client_divert(GkrellmCpuReadFunc read_func)
 	{
 	read_cpu_data = read_func;
 	}
@@ -538,7 +538,7 @@ cpu_expose_event(GtkWidget *widget, GdkEventExpose *ev)
 			pixmap = cp->panel->pixmap;
 		if (pixmap)
 			{
-			gdk_draw_drawable(widget->window, gkrellm_draw_GC(1), pixmap,
+			gdk_draw_drawable(gtk_widget_get_window(widget), gkrellm_draw_GC(1), pixmap,
 					ev->area.x, ev->area.y, ev->area.x, ev->area.y,
 					ev->area.width, ev->area.height);
 			break;
@@ -575,7 +575,7 @@ cb_cpu_extra(GtkWidget *widget, GdkEventButton *ev)
 	}
 
 static void
-setup_cpu_scaling(GkrellmChartconfig *cf)
+setup_cpu_scaling(GkrellmChartconfig *cf, gpointer data)
 	{
 	gint	grids;
 
@@ -741,7 +741,7 @@ static gchar			*nice_color_string,
 						*nice_grid_color_string;
 
 static void
-cb_height(GkrellmChartconfig *cf, CpuMon *cpu)
+cb_height(GkrellmChartconfig *cf, gpointer data)
 	{
 	GList			*list;
 	GkrellmChart	*cp;
@@ -879,7 +879,7 @@ create_cpu(GtkWidget *vbox, gint first_create)
 		gkrellm_chartconfig_fixed_grids_connect(cp->config,
 					setup_cpu_scaling, NULL);
 		gkrellm_chartconfig_height_connect(cp->config, cb_height, cpu);
-		setup_cpu_scaling(cp->config);
+		setup_cpu_scaling(cp->config, NULL);
 
 		cpu->sensor_decal = cpu->fan_decal = NULL;
 		if (show_panel_labels)
@@ -902,14 +902,14 @@ create_cpu(GtkWidget *vbox, gint first_create)
 
 		if (first_create)
 			{
-			g_signal_connect(G_OBJECT (cp->drawing_area), "expose_event",
+			g_signal_connect(G_OBJECT (cp->drawing_area), "expose-event",
 					G_CALLBACK(cpu_expose_event), NULL);
-			g_signal_connect(G_OBJECT (p->drawing_area), "expose_event",
+			g_signal_connect(G_OBJECT (p->drawing_area), "expose-event",
 					G_CALLBACK(cpu_expose_event), NULL);
 
-			g_signal_connect(G_OBJECT(cp->drawing_area), "button_press_event",
+			g_signal_connect(G_OBJECT(cp->drawing_area), "button-press-event",
 					G_CALLBACK(cb_cpu_extra), NULL);
-			g_signal_connect(G_OBJECT(p->drawing_area), "button_press_event",
+			g_signal_connect(G_OBJECT(p->drawing_area), "button-press-event",
 					G_CALLBACK(cb_panel_press), NULL);
 			}
 		else
@@ -1128,7 +1128,7 @@ static void
 cb_alert_config(GkrellmAlert *ap, gpointer data)
 	{
 #if !defined(WIN32)
-	alert_includes_nice = GTK_TOGGLE_BUTTON(alert_config_nice_button)->active;
+	alert_includes_nice = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(alert_config_nice_button));
 #endif
 	dup_cpu_alert();
 	}
@@ -1194,7 +1194,7 @@ cb_sensor_separate(GtkWidget *button, gpointer data)
     {
 	GList	*list;
 
-	sensor_separate_mode = GTK_TOGGLE_BUTTON(button)->active;
+	sensor_separate_mode = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
 	for (list = cpu_mon_list; list; list = list->next)
 		fix_panel((CpuMon *) list->data);
 	}
@@ -1208,7 +1208,7 @@ cb_show_panel_labels(GtkWidget *button, gpointer data)
 	GList			*list;
 	gboolean		rebuild_temps = FALSE, rebuild_fans = FALSE;
 
-	show_panel_labels = GTK_TOGGLE_BUTTON(button)->active;
+	show_panel_labels = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
 	style = gkrellm_panel_style(style_id);
 
 	for (list = cpu_mon_list; list; list = list->next)
@@ -1251,7 +1251,7 @@ cb_show_panel_labels(GtkWidget *button, gpointer data)
 static void
 cb_omit_nice(GtkWidget *button, gpointer data)
     {
-	omit_nice_mode = GTK_TOGGLE_BUTTON(button)->active;
+	omit_nice_mode = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
 	}
 
 static void
@@ -1282,7 +1282,7 @@ cb_enable(GtkWidget *button, gpointer data)
 	gint		i;
 	gboolean	enabled, rebuild_temps = FALSE, rebuild_fans = FALSE;
 
-	enabled = GTK_TOGGLE_BUTTON(button)->active;
+	enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
 	any_cpu_enabled = any_real_cpu_enabled = FALSE;
 	for (i = 0, list = cpu_mon_list; list; ++i, list = list->next)
 		{
@@ -1326,7 +1326,7 @@ cb_enable(GtkWidget *button, gpointer data)
 static void
 cb_config_tracking(GtkWidget *button, gpointer data)
 	{
-	config_tracking = GTK_TOGGLE_BUTTON(button)->active;
+	config_tracking = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
 	}
 
 static void
@@ -1436,34 +1436,34 @@ create_cpu_tab(GtkWidget *tab_vbox)
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
 
-	text_format_combo_box = gtk_combo_box_entry_new_text();
+	text_format_combo_box = gtk_combo_box_text_new_with_entry();
 	gtk_box_pack_start(GTK_BOX(hbox), text_format_combo_box, TRUE, TRUE, 0);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		text_format);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		DEFAULT_TEXT_FORMAT);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		_("\\f$L\\n$T"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		_("\\fu \\.$u\\n\\fs \\.$s"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		_("\\ww\\D2\\f\\au\\.$u\\D1\\f\\as\\.$s"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		_("\\ww\\D3\\f\\au\\.$u\\D0\\f\\as\\.$s"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		_("\\ww\\D2\\f\\au\\.$u\\D1\\f\\as\\.$s\\D3\\f\\r$L"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		_("\\ww\\D2\\f\\au\\.$u\\D1\\f\\as\\.$s\\D3\\f\\r$L"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		_("\\ww\\D3\\f$L\\n\\f\\as\\.$s\\n\\f\\au\\.$u"));
 
 	if (!nice_time_unsupported)
 		{
-		gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 			"\\ww\\C\\f$L\\D5\\f\\an\\.$n\\D2\\f\\au\\.$u\\D1\\f\\as\\.$s");
 		}
 	gtk_combo_box_set_active(GTK_COMBO_BOX(text_format_combo_box), 0);
-	g_signal_connect(G_OBJECT(GTK_COMBO_BOX(text_format_combo_box)), "changed",
+	g_signal_connect(G_OBJECT(text_format_combo_box), "changed",
 			G_CALLBACK(cb_text_format), NULL);
 
 	vbox1 = gkrellm_gtk_category_vbox(vbox,
@@ -1529,7 +1529,7 @@ static GkrellmMonitor	monitor_cpu =
 	create_cpu_tab,		/* The config tab create function	*/
 	NULL,				/* Apply the config function		*/
 
-	save_cpu_config,	/* Save user conifg			*/
+	save_cpu_config,	/* Save user config			*/
 	load_cpu_config,	/* Load user config			*/
 	CPU_CONFIG_KEYWORD,	/* config keyword			*/
 
