@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -103,10 +103,9 @@ static gint		assign_method;
 static gboolean	sys_handles_composite_reset;
 static gboolean	units_are_blocks;
 
-static void		(*read_disk_data)();
-static gchar	*(*name_from_device)();
-static gint		(*order_from_name)();
-
+static GkrellmDiskReadFunc read_disk_data;
+static GkrellmDiskNameFromDeviceFunc name_from_device;
+static GkrellmDiskOrderFromNameFunc order_from_name;
 
 
 DiskMon *
@@ -255,8 +254,9 @@ setup_disk_interface(void)
 
 /* ------------- Disk monitor to system dependent interface ------------- */
 void
-gkrellm_disk_client_divert(void (*read_func)(),
-		gchar *(*name_from_device_func)(), gint (*order_from_name_func)())
+gkrellm_disk_client_divert(GkrellmDiskReadFunc read_func,
+				GkrellmDiskNameFromDeviceFunc name_from_device_func,
+				GkrellmDiskOrderFromNameFunc order_from_name_func)
 	{
 	read_disk_data = read_func;
 	name_from_device = name_from_device_func;
@@ -667,7 +667,7 @@ disk_expose_event(GtkWidget *widget, GdkEventExpose *ev)
 			pixmap = cp->panel->pixmap;
 		if (pixmap)
 			{
-			gdk_draw_drawable(widget->window, gkrellm_draw_GC(1), pixmap,
+			gdk_draw_drawable(gtk_widget_get_window(widget), gkrellm_draw_GC(1), pixmap,
 				  ev->area.x, ev->area.y, ev->area.x, ev->area.y,
 				  ev->area.width, ev->area.height);
 			break;
@@ -703,9 +703,10 @@ cb_disk_extra(GtkWidget *widget, GdkEventButton *ev)
 	}
 
 static void
-setup_disk_scaling(GkrellmChartconfig *cf, GkrellmChart *cp)
+setup_disk_scaling(GkrellmChartconfig *cf, gpointer data)
 	{
 	gint	grids, res;
+	GkrellmChart *cp = (GkrellmChart*)data;
 
 	grids = gkrellm_get_chartconfig_fixed_grids(cf);
 	if (!grids)
@@ -806,14 +807,14 @@ create_disk_monitor(DiskMon *disk, gint first_create)
 
 	if (first_create)
 		{
-		g_signal_connect(G_OBJECT(cp->drawing_area), "expose_event",
+		g_signal_connect(G_OBJECT(cp->drawing_area), "expose-event",
 				G_CALLBACK(disk_expose_event), NULL);
-		g_signal_connect(G_OBJECT (p->drawing_area), "expose_event",
+		g_signal_connect(G_OBJECT (p->drawing_area), "expose-event",
 				G_CALLBACK(disk_expose_event), NULL);
 
-		g_signal_connect(G_OBJECT(cp->drawing_area), "button_press_event",
+		g_signal_connect(G_OBJECT(cp->drawing_area), "button-press-event",
 				G_CALLBACK(cb_disk_extra), NULL);
-		g_signal_connect(G_OBJECT(p->drawing_area), "button_press_event",
+		g_signal_connect(G_OBJECT(p->drawing_area), "button-press-event",
 				G_CALLBACK(cb_panel_press), NULL);
 		}
 	else
@@ -1183,9 +1184,9 @@ cb_alert_config(GkrellmAlert *ap, DiskMon *disk)
 	gboolean		valid;
 
 	disk->alert_uses_read =
-				GTK_TOGGLE_BUTTON(disk->alert_config_read_button)->active;
+				gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(disk->alert_config_read_button));
 	disk->alert_uses_write =
-				GTK_TOGGLE_BUTTON(disk->alert_config_write_button)->active;
+				gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(disk->alert_config_write_button));
 	if (!gkrellm_config_window_shown())
 		return;
 	model = gtk_tree_view_get_model(treeview);
@@ -1222,8 +1223,8 @@ cb_alert_config_button(GtkWidget *button, DiskMon *disk)
 	{
 	gboolean	read, write;
 
-	read = GTK_TOGGLE_BUTTON(disk->alert_config_read_button)->active;
-	write = GTK_TOGGLE_BUTTON(disk->alert_config_write_button)->active;
+	read = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(disk->alert_config_read_button));
+	write = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(disk->alert_config_write_button));
 	if (!read && !write)
 		{
 		gtk_toggle_button_set_active(
@@ -1452,7 +1453,6 @@ create_disk_tab(GtkWidget *tab_vbox)
 	disk_model = model;
 
 	treeview = GTK_TREE_VIEW(gtk_tree_view_new_with_model(model));
-	gtk_tree_view_set_rules_hint(treeview, TRUE);
 
 	renderer = gtk_cell_renderer_toggle_new();
 	gtk_tree_view_insert_column_with_attributes(treeview, -1, _("Enable"),
@@ -1502,20 +1502,20 @@ create_disk_tab(GtkWidget *tab_vbox)
 	vbox1 = gkrellm_gtk_category_vbox(vbox,
 				_("Format String for Chart Labels"),
 				4, 0, TRUE);
-	text_format_combo_box = gtk_combo_box_entry_new_text();
+	text_format_combo_box = gtk_combo_box_text_new_with_entry();
 	gtk_box_pack_start(GTK_BOX(vbox1), text_format_combo_box, FALSE, FALSE, 0);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		text_format);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		DEFAULT_TEXT_FORMAT);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		"\\c\\f$M\\n$T");
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		"\\c\\f$M\\b$T");
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		_("\\f\\ww\\r\\f$M\\D2\\f\\ar\\. $r\\D1\\f\\aw\\. $w"));
 	gtk_combo_box_set_active(GTK_COMBO_BOX(text_format_combo_box), 0);
-	g_signal_connect(G_OBJECT(GTK_COMBO_BOX(text_format_combo_box)), "changed",
+	g_signal_connect(G_OBJECT(text_format_combo_box), "changed",
 			G_CALLBACK(cb_text_format), NULL);
 
 	vbox1 = gkrellm_gtk_category_vbox(vbox,
@@ -1549,7 +1549,7 @@ static GkrellmMonitor	monitor_disk =
 	create_disk_tab,	/* The config tab create function	*/
 	NULL,				/* Instant apply */
 
-	save_disk_config,	/* Save user conifg			*/
+	save_disk_config,	/* Save user config			*/
 	load_disk_config,	/* Load user config			*/
 	DISK_CONFIG_KEYWORD, /* config keyword			*/
 
