@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2014 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -39,6 +39,7 @@
 #include "config.h"
 #endif
 #include "log.h"
+#include "gkrellm-version.h"
 
 #if !defined(WIN32)
 #include <sys/param.h>
@@ -106,16 +107,6 @@
 
 /* -------------------------------------------------------------------
 */
-#define	GKRELLM_VERSION_MAJOR	2
-#define	GKRELLM_VERSION_MINOR	3
-#define	GKRELLM_VERSION_REV		7
-#define	GKRELLM_EXTRAVERSION	""
-
-#define GKRELLM_CHECK_VERSION(major,minor,rev)    \
-	(GKRELLM_VERSION_MAJOR > (major) || \
-	(GKRELLM_VERSION_MAJOR == (major) && GKRELLM_VERSION_MINOR > (minor)) || \
-	(GKRELLM_VERSION_MAJOR == (major) && GKRELLM_VERSION_MINOR == (minor) && \
-	GKRELLM_VERSION_REV >= (rev)))
 
 #define	GKRELLM_DIR				".gkrellm2"
 #define	GKRELLM_USER_CONFIG		".gkrellm2/user-config"
@@ -261,8 +252,8 @@ typedef struct
 #define DF_LOCAL_PIXMAPS		0x4
 #define	DF_OVERLAY_PIXMAPS		0x8
 #define	DF_TEXT_OVERLAPS		0x10
-#define	DF_SCROLL_TEXT_DIVERTED	0x20
-#define	DF_SCROLL_TEXT_CENTER	0x40
+#define	DF_TEXT_CENTER			0x20
+#define	DF_SCROLL_TEXT_DIVERTED	0x40
 #define	DF_SCROLL_TEXT_H_LOOP	0x80
 #define	DF_SCROLL_TEXT_V_LOOP	0x100
 #define	DF_TEXT_USE_MARKUP		0x200
@@ -506,6 +497,7 @@ typedef struct
 	gint		h_configure;
 
 	PangoLayout	*layout;
+	PangoLayout	 *label_layout;
 
 	gint		transparency;
 	gboolean	modified;		/* True if decal/krell modified.	*/
@@ -525,14 +517,6 @@ typedef struct
 	GkrellmPanel;
 
 
-typedef struct
-	{
-	void		(*func)();
-	gpointer	data;
-	}
-	GkrellmCallback;
-
-
 #define CHART_WIDTH_MAX	1000
 #define CHART_WIDTH_MIN	25
 
@@ -544,14 +528,15 @@ typedef struct
 #define	NO_CONFIG_AUTO_GRID_RESOLUTION	1
 #define	NO_CONFIG_FIXED_GRIDS			2
 
-typedef struct
+typedef struct GkrellmChartconfig GkrellmChartconfig;
+struct GkrellmChartconfig
 	{
 	gint		flags;
 	gboolean	config_loaded;
 	gboolean	log;
 
 	gint		h;
-	void		(*cb_height)();
+	void		(*cb_height)(GkrellmChartconfig *config, gpointer data);
 	gpointer	cb_height_data;
 	GtkWidget	*height_spin_button;
 
@@ -564,7 +549,7 @@ typedef struct
 	gboolean	auto_grid_resolution;
 	gboolean	auto_resolution_stick;
 	gboolean	sequence_125;
-	void		(*cb_grid_resolution)();
+	void		(*cb_grid_resolution)(GkrellmChartconfig *config, gpointer data);
 	gpointer	cb_grid_resolution_data;
 	GtkWidget	*grid_resolution_spin_button;
 	GtkWidget	*auto_resolution_control_menubar;
@@ -581,7 +566,7 @@ typedef struct
 				width;
 
 	gboolean	fixed_grids;
-	void		(*cb_fixed_grids)();
+	void		(*cb_fixed_grids)(GkrellmChartconfig *config, gpointer data);
 	gpointer	cb_fixed_grids_data;
 	GtkWidget	*fixed_grids_spin_button;
 
@@ -589,8 +574,7 @@ typedef struct
 	GList		**chart_cd_list;
 
 	gboolean	cb_block;
-	}
-	GkrellmChartconfig;
+	};
 
   /* GkrellmCharts are drawn in layers and each data value drawn has its own
   |  layer (the GkrellmChartdata struct -> image/color of the drawn data and
@@ -721,11 +705,12 @@ typedef struct
 	gchar		*label;
 	gulong		current,
 				previous,
+				wrap,
 				discard;
 	gboolean	monotonic;
 	GkrellmChartlayer layer;	/* The image + grid for this data layer */
 	GdkBitmap	*data_bitmap;	/* Draw data here, use as clipmask for layer*/
-	gint		*data;
+	gulong		*data;
 
 	gint		draw_style;
 	gboolean	inverted;
@@ -742,18 +727,19 @@ typedef struct
 	gint		y,				/* Each data layer draws at an offset y and */
 				h,				/* within height h of its parent GkrellmChart*/
 				w;				/* Width of data allocated.				*/
-	gint		maxval;
+	gulong		maxval;
 	}
 	GkrellmChartdata;
 
 
-typedef struct
+typedef struct GkrellmDecalbutton GkrellmDecalbutton;
+struct GkrellmDecalbutton
 	{
 	GkrellmPanel *panel;
 	GkrellmDecal *decal;
-	void		(*cb_button_click)();
+	void		(*cb_button_click)(GkrellmDecalbutton *b, gpointer data);
 	gpointer	data;
-	gint		(*cb_in_button)();
+	gint		(*cb_in_button)(GkrellmDecalbutton *b, GdkEventButton *ev, gpointer data);
 	gpointer	in_button_data;
 	gpointer	privat;
 	gint		cur_index;
@@ -761,10 +747,9 @@ typedef struct
 	gint		saved_index;
 	gint		sensitive;
 	gint		type;
-	void		(*cb_button_right_click)();
+	void		(*cb_button_right_click)(GkrellmDecalbutton *b, gpointer data);
 	gpointer	right_data;
-	}
-	GkrellmDecalbutton;
+	};
 
 
 
@@ -788,20 +773,21 @@ typedef struct
 /* ------- Alerts ------- */
 #define	GKRELLM_ALERTCONFIG_KEYWORD			"alert_config"
 
+typedef struct GkrellmAlert GkrellmAlert;
 typedef struct
 	{
 	struct _GkrellmMonitor	*mon;
 	gchar		*name,
 				*tab_name;
-	void		(*warn_func)(),
-				(*alarm_func)(),
-				(*update_func)(),
-				(*check_func)(),
-				(*destroy_func)();
-	void		(*config_create_func)(),
-				(*config_apply_func)(),
-				(*config_save_func)(),
-				(*config_load_func)();
+	void		(*warn_func)(GkrellmAlert *alert, gpointer data, gboolean state),
+				(*alarm_func)(GkrellmAlert *alert, gpointer data, gboolean state),
+				(*update_func)(GkrellmAlert *alert, gpointer data),
+				(*check_func)(GkrellmAlert *alert, gpointer data, gfloat value),
+				(*destroy_func)(GkrellmAlert *alert, gpointer data);
+	void		(*config_create_func)(GtkWidget *vbox, GkrellmAlert *alert, gpointer data),
+				(*config_apply_func)(GkrellmAlert *alert, gpointer data, gboolean closing),
+				(*config_save_func)(GkrellmAlert *alert, gpointer data, FILE *f, gchar *p, gchar *id),
+				(*config_load_func)(GkrellmAlert *alert, gchar *config_id, gchar *alert_id);
 	}
 	GkrellmAlertPlugin;
 
@@ -844,7 +830,7 @@ typedef struct
 	}
 	GkrellmAlertkrell;
 
-typedef struct
+struct GkrellmAlert
 	{
 	GkrellmPanel *panel;
 	gchar		*name,
@@ -867,15 +853,15 @@ typedef struct
 				alarm_repeat;
 	gint		delay;
 
-	void		(*cb_trigger)();
+	void		(*cb_trigger)(GkrellmAlert *alert, gpointer data);
 	gpointer	cb_trigger_data;
 	void		(*cb_stop)();
 	gpointer	cb_stop_data;
-	void		(*cb_config)();
+	void		(*cb_config)(GkrellmAlert *alert, gpointer data);
 	gpointer	cb_config_data;
-	void		(*cb_config_create)();
+	void		(*cb_config_create)(GkrellmAlert *alert, GtkWidget *vbox1, gpointer data);
 	gpointer	cb_config_create_data;
-	void		(*cb_command_process)();
+	void		(*cb_command_process)(GkrellmAlert *alert, gchar *src, gchar *buf, gint size, void* target);
 	gpointer	cb_command_process_data;
 
 	GtkWidget	*config_window,
@@ -907,8 +893,7 @@ typedef struct
 
 	gchar		*id_string;		/* For unique alert names for alert plugins */
 	GList		*plugin_list;
-	}
-	GkrellmAlert;
+	};
 
 /* ------------------------ */
 
@@ -1079,5 +1064,4 @@ typedef struct _GkrellmMonitor
 
 #include "gkrellm-public-proto.h"
 
-#endif // GKRELLM_H
-
+#endif
\ No newline at end of file
