@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -64,8 +64,8 @@ typedef struct
 
 ProcMon	proc;
 
-void	(*read_proc_data)();
-void	(*read_user_data)();
+static GkrellmProcReadProcFunc read_proc_data;
+static GkrellmProcReadUsersFunc read_user_data;
 
 GkrellmAlert	*load_alert,
 				*processes_alert,
@@ -83,8 +83,8 @@ setup_proc_interface(void)
 	}
 
 void
-gkrellm_proc_client_divert(void (*read_proc_func)(),
-			void (*read_users_func)())
+gkrellm_proc_client_divert(GkrellmProcReadProcFunc read_proc_func,
+			GkrellmProcReadUsersFunc read_users_func)
 	{
 	read_proc_data = read_proc_func;
 	read_user_data = read_users_func;
@@ -309,7 +309,7 @@ proc_expose_event(GtkWidget *widget, GdkEventExpose *ev)
 			pixmap = cp->panel->pixmap;
 		}
 	if (pixmap)
-		gdk_draw_drawable(widget->window, gkrellm_draw_GC(1), pixmap,
+		gdk_draw_drawable(gtk_widget_get_window(widget), gkrellm_draw_GC(1), pixmap,
 				  ev->area.x, ev->area.y, ev->area.x, ev->area.y,
 				  ev->area.width, ev->area.height);
 	return FALSE;
@@ -333,7 +333,7 @@ cb_proc_extra(GtkWidget *widget, GdkEventButton *ev)
 	}
 
 static void
-setup_proc_scaling(void)
+setup_proc_scaling(GkrellmChartconfig *config, gpointer data)
 	{
 	GkrellmChart	*cp		= proc.chart;
 	gint			grids, res, new_fork_scaling;
@@ -567,7 +567,7 @@ create_proc_monitor(GtkWidget *vbox, gint first_create)
 					_("Average process load per minute"));
 
 	gkrellm_alloc_chartdata(cp);
-	setup_proc_scaling();
+	setup_proc_scaling(NULL, NULL);
 
 	/* I put motherboard temp on Proc panel (if temperature sensors found)
 	*/
@@ -585,13 +585,13 @@ create_proc_monitor(GtkWidget *vbox, gint first_create)
 	new_text_format = TRUE;
 	if (first_create)
 		{
-		g_signal_connect(G_OBJECT(cp->drawing_area), "expose_event",
+		g_signal_connect(G_OBJECT(cp->drawing_area), "expose-event",
 				G_CALLBACK(proc_expose_event), NULL);
-		g_signal_connect(G_OBJECT(p->drawing_area), "expose_event",
+		g_signal_connect(G_OBJECT(p->drawing_area), "expose-event",
 				G_CALLBACK(proc_expose_event), NULL);
-		g_signal_connect(G_OBJECT(cp->drawing_area),"button_press_event",
+		g_signal_connect(G_OBJECT(cp->drawing_area),"button-press-event",
 				G_CALLBACK(cb_proc_extra), NULL);
-		g_signal_connect(G_OBJECT(p->drawing_area), "button_press_event",
+		g_signal_connect(G_OBJECT(p->drawing_area), "button-press-event",
 				G_CALLBACK(cb_panel_press), NULL);
 		}
 	else
@@ -806,7 +806,7 @@ gkrellm_proc_set_sensor(gpointer sr, gint type)
 static void
 cb_sensor_separate(GtkWidget *button, gpointer data)
 	{
-	sensor_separate_mode = GTK_TOGGLE_BUTTON(button)->active;
+	sensor_separate_mode = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
 	fix_panel();
 	}
 
@@ -828,7 +828,7 @@ cb_enable(GtkWidget *button, gpointer data)
     {
 	gboolean enabled;
 
-	enabled = GTK_TOGGLE_BUTTON(button)->active;
+	enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
 	if (enabled && ! proc.enabled)
 		{
 		create_proc_monitor(proc.vbox, TRUE);
@@ -960,16 +960,16 @@ create_proc_tab(GtkWidget *tab_vbox)
 				_("Format String for Chart Labels"),
 				4, 0, TRUE);
 
-	text_format_combo_box = gtk_combo_box_entry_new_text();
+	text_format_combo_box = gtk_combo_box_text_new_with_entry();
 	gtk_widget_set_size_request (GTK_WIDGET(text_format_combo_box), 350, -1);
 	gtk_box_pack_start(GTK_BOX(vbox1), text_format_combo_box, FALSE, FALSE, 2);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box), text_format);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box), text_format);
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 			_(DEFAULT_TEXT_FORMAT));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 			_("\\f$L\\r\\f$F \\w88\\b\\p\\a$p\\f procs\\n\\e$u\\f users"));
 	gtk_combo_box_set_active(GTK_COMBO_BOX(text_format_combo_box), 0);
-	g_signal_connect(G_OBJECT(GTK_COMBO_BOX(text_format_combo_box)), "changed",
+	g_signal_connect(G_OBJECT(text_format_combo_box), "changed",
 			G_CALLBACK(cb_text_format), NULL);
 
 	vbox1 = gkrellm_gtk_category_vbox(vbox,
@@ -1014,7 +1014,7 @@ static GkrellmMonitor	monitor_proc =
 	create_proc_tab,	/* The config tab create function	*/
 	NULL,				/* Instant apply */
 
-	save_proc_config,	/* Save user conifg			*/
+	save_proc_config,	/* Save user config			*/
 	load_proc_config,	/* Load user config			*/
 	PROC_CONFIG_KEYWORD, /* config keyword			*/
 
