@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |  darwin.c code is Copyright (c) Ben Hines <bhines@alumni.ucsd.edu>
 |
@@ -289,7 +289,7 @@ static GPtrArray *s_disk_ptr_array = NULL;
 
 
 static GK_DARWIN_DISK *
-gk_darwin_disk_new()
+gk_darwin_disk_new(void)
 {
 	return g_new0(GK_DARWIN_DISK, 1);
 }
@@ -474,7 +474,7 @@ gkrellm_sys_disk_read_data(void)
 
         CFRelease(storage_driver_stats);
         IOObjectRelease(storage_driver);
-    } // for()
+    }
 }
 
 gboolean
