@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |  netbsd.c code is Copyright (C):
 |             Anthony Mallet <anthony.mallet@useless-ficus.net>
@@ -563,7 +563,7 @@ gkrellm_sys_battery_read_data(void)
 }
 
 gboolean
-gkrellm_sys_battery_init()
+gkrellm_sys_battery_init(void)
 {
    int fd;			/* file desc. for /dev/sysmon or /dev/apm */
    envsys_basic_info_t info;	/* sensor misc. info */
@@ -773,7 +773,7 @@ static const struct gkrellm_inet_fam {
     {0, NULL} };
 
 void
-gkrellm_sys_inet_read_tcp_data()
+gkrellm_sys_inet_read_tcp_data(void)
 {
 	ActiveTCP tcp;
 	int mib[CTL_MAXNAME], i;
