@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |  OpenBSD code derived from FreeBSD code by: Hajimu UMEMOTO <ume@FreeBSD.org>
 |
@@ -334,7 +334,7 @@ gkrellm_sys_battery_read_data(void)
 	}
 
 gboolean
-gkrellm_sys_battery_init()
+gkrellm_sys_battery_init(void)
 	{
 	return TRUE;
 	}
@@ -347,7 +347,7 @@ gkrellm_sys_battery_read_data(void)
 	}
 
 gboolean
-gkrellm_sys_battery_init()
+gkrellm_sys_battery_init(void)
 	{
 	return FALSE;
 	}
