@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -54,7 +54,7 @@ static gchar	gkrellm_decimal_point,
 				mbmon_decimal_point;
 static gboolean	mbmon_need_decimal_point_fix;
 
-static gboolean (*mbmon_check_func)();
+static gboolean (*mbmon_check_func)(gboolean);
 
 static gboolean
 mbmon_decimal_point_fix(gchar *buf)
