@@ -1,12 +1,12 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |                2002      Bill Nalen
-|                2007-2019 Stefan Gehn
+|                2007-2024 Stefan Gehn
 |
 |  Authors:  Bill Wilson    billw@gkrellm.net
 |            Bill Nalen     bill@nalens.com
 |            Stefan Gehn    stefan+gkrellm@srcbox.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -692,7 +692,7 @@ typedef struct _GK_NET
 static GPtrArray *s_net_ptr_array = NULL;
 
 static GK_NET *
-gk_net_new()
+gk_net_new(void)
 {
 	return g_new0(GK_NET, 1);
 }
@@ -828,7 +828,7 @@ typedef struct _GK_DISK
 static GPtrArray *s_disk_ptr_array = NULL;
 
 static GK_DISK *
-gk_disk_new()
+gk_disk_new(void)
 {
 	return g_new0(GK_DISK, 1);
 }
@@ -1484,7 +1484,7 @@ void gkrellm_sys_battery_read_data(void)
 		time_left);
 }
 
-gboolean gkrellm_sys_battery_init()
+gboolean gkrellm_sys_battery_init(void)
 	{
 	gkrellm_debug(DEBUG_SYSDEP, "INIT battery monitoring\n");
 	return TRUE;
@@ -1881,6 +1881,8 @@ gboolean gkrellm_sys_uptime_init(void)
 
 typedef void (WINAPI *PGetNativeSystemInfo)(SYSTEM_INFO *);
 
+typedef NTSTATUS (WINAPI *RtlGetVersionFunc)(OSVERSIONINFOEXW *);
+
 gchar *gkrellm_sys_get_system_name(void)
 	{
 	static gboolean	 have_sys_name;
@@ -1888,6 +1890,7 @@ gchar *gkrellm_sys_get_system_name(void)
 	OSVERSIONINFOEXW vi;
 	SYSTEM_INFO si;
 	PGetNativeSystemInfo pGNSI;
+	RtlGetVersionFunc rtlGetVersionFunc;
 
 	if (have_sys_name)
 		return sysname;
@@ -1900,8 +1903,22 @@ gchar *gkrellm_sys_get_system_name(void)
 	// Query version info
 	memset(&vi, 0, sizeof(OSVERSIONINFOEXW));
 	vi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEXW);
-	if (!GetVersionExW((OSVERSIONINFOW *)(&vi)))
-		return sysname;
+
+	rtlGetVersionFunc = (RtlGetVersionFunc)GetProcAddress(
+			GetModuleHandleW(L"ntdll"), "RtlGetVersion");
+
+	if (rtlGetVersionFunc != NULL) {
+		if (rtlGetVersionFunc(&vi) != 0)
+			return sysname;
+	} else {
+		if (!GetVersionExW((OSVERSIONINFOW *)(&vi)))
+			return sysname;
+	}
+
+	gkrellm_debug(DEBUG_SYSDEP, "OS Version: %d.%d (build %d)\n",
+		vi.dwMajorVersion,
+		vi.dwMinorVersion,
+		vi.dwBuildNumber);
 
 	// We actually only support decoding NT-based version info
 	if (vi.dwPlatformId != VER_PLATFORM_WIN32_NT)
@@ -1920,7 +1937,29 @@ gchar *gkrellm_sys_get_system_name(void)
 	/* NT Workstation identifies some Client/Desktop Windows version */
 	gboolean isWks = (vi.wProductType == VER_NT_WORKSTATION);
 
-	if (vi.dwMajorVersion == 6)
+	if (vi.dwMajorVersion == 10)
+		{
+		if (vi.dwMinorVersion == 0)
+			{
+			if (isWks)
+				{
+				if (vi.dwBuildNumber >= 22000)
+					g_strlcpy(sysname, "Windows 11", sizeof(sysname));
+				else
+					g_strlcpy(sysname, "Windows 10", sizeof(sysname));
+				}
+			else
+				{
+				if (vi.dwBuildNumber >= 20348)
+					g_strlcpy(sysname, "Windows Server 2022", sizeof(sysname));
+				else if (vi.dwBuildNumber >= 17763)
+					g_strlcpy(sysname, "Windows Server 2019", sizeof(sysname));
+				else
+					g_strlcpy(sysname, "Windows Server 2016", sizeof(sysname));
+				}
+			}
+		}
+	else if (vi.dwMajorVersion == 6)
 		{
 		if (vi.dwMinorVersion == 0)
 			g_strlcpy(sysname, isWks ? "Windows Vista" : "Windows Server 2008", sizeof(sysname));
@@ -1962,180 +2001,3 @@ gchar *gkrellm_sys_get_system_name(void)
 
 	return sysname;
 	}
-
-
-/* ===================================================================== */
-/* Misc functions */
-/* ===================================================================== */
-
-/*
-* Copyright (c) 1983, 1990, 1993
-* The Regents of the University of California. All rights reserved.
-*
-* Redistribution and use in source and binary forms, with or without
-* modification, are permitted provided that the following conditions
-* are met:
-* 1. Redistributions of source code must retain the above copyright
-* notice, this list of conditions and the following disclaimer.
-* 2. Redistributions in binary form must reproduce the above copyright
-* notice, this list of conditions and the following disclaimer in the
-* documentation and/or other materials provided with the distribution.
-* 3. All advertising materials mentioning features or use of this software
-* must display the following acknowledgement:
-* This product includes software developed by the University of
-* California, Berkeley and its contributors.
-* 4. Neither the name of the University nor the names of its contributors
-* may be used to endorse or promote products derived from this software
-* without specific prior written permission.
-*
-* THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
-* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-* ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
-* FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-* DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-* OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-* HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-* LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-* SUCH DAMAGE.
-*/
-
-/*
-* Portions Copyright (c) 1993 by Digital Equipment Corporation.
-*
-* Permission to use, copy, modify, and distribute this software for any
-* purpose with or without fee is hereby granted, provided that the above
-* copyright notice and this permission notice appear in all copies, and that
-* the name of Digital Equipment Corporation not be used in advertising or
-* publicity pertaining to distribution of the document or software without
-* specific, written prior permission.
-*
-* THE SOFTWARE IS PROVIDED "AS IS" AND DIGITAL EQUIPMENT CORP. DISCLAIMS ALL
-* WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES
-* OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL DIGITAL EQUIPMENT
-* CORPORATION BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL
-* DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
-* PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
-* ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
-* SOFTWARE.
-*/
-
-/*
-* Portions Copyright (c) 1996-1999 by Internet Software Consortium.
-*
-* Permission to use, copy, modify, and distribute this software for any
-* purpose with or without fee is hereby granted, provided that the above
-* copyright notice and this permission notice appear in all copies.
-*
-* THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE CONSORTIUM DISCLAIMS
-* ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES
-* OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL INTERNET SOFTWARE
-* CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL
-* DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
-* PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
-* ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
-* SOFTWARE.
-*/
-
-/* BeOS doesn't yet have it's own inet_aton and Bind won't be ported
-* until R5, so this is from a Bind 8 distribution. It's currently untested.
-*/
-
-int inet_aton(const char *cp, struct in_addr *addr) {
-u_long val;
-int base, n;
-char c;
-short parts[4];
-short *pp = parts;
-int digit;
-
-c = *cp;
-for (;;) {
-/*
-* Collect number up to ``.''.
-* Values are specified as for C:
-* 0x=hex, 0=octal, isdigit=decimal.
-*/
-if (!isdigit(c))
-return (0);
-val = 0; base = 10; digit = 0;
-if (c == '0') {
-c = *++cp;
-if (c == 'x' || c == 'X')
-base = 16, c = *++cp;
-else {
-base = 8;
-digit = 1 ;
-}
-}
-for (;;) {
-if (isascii(c) && isdigit(c)) {
-if (base == 8 && (c == '8' || c == '9'))
-return (0);
-val = (val * base) + (c - '0');
-c = *++cp;
-digit = 1;
-} else if (base == 16 && isascii(c) && isxdigit(c)) {
-val = (val << 4) |
-(c + 10 - (islower(c) ? 'a' : 'A'));
-c = *++cp;
-digit = 1;
-} else
-break;
-}
-if (c == '.') {
-/*
-* Internet format:
-* a.b.c.d
-* a.b.c (with c treated as 16 bits)
-* a.b (with b treated as 24 bits)
-*/
-if (pp >= parts + 3 || val > 0xff)
-return (0);
-*pp++ = val;
-c = *++cp;
-} else
-break;
-}
-/*
-* Check for trailing characters.
-*/
-if (c != '\0' && (!isascii(c) || !isspace(c)))
-return (0);
-/*
-* Did we get a valid digit?
-*/
-if (!digit)
-return (0);
-/*
-* Concoct the address according to
-* the number of parts specified.
-*/
-n = pp - parts + 1;
-switch (n) {
-case 1: /* a -- 32 bits */
-break;
-
-case 2: /* a.b -- 8.24 bits */
-if (val > 0xffffff)
-return (0);
-val |= parts[0] << 24;
-break;
-
-case 3: /* a.b.c -- 8.8.16 bits */
-if (val > 0xffff)
-return (0);
-val |= (parts[0] << 24) | (parts[1] << 16);
-break;
-
-case 4: /* a.b.c.d -- 8.8.8.8 bits */
-if (val > 0xff)
-return (0);
-val |= (parts[0] << 24) | (parts[1] << 16) | (parts[2] << 8);
-break;
-}
-if (addr != NULL)
-addr->s_addr = htonl(val);
-return (1);
-}
