@@ -1,10 +1,10 @@
  /* GKrellM Windows Portion
 |  Copyright (C) 2002 Bill Nalen
-|                2007-2019 Stefan Gehn
+|                2007-2024 Stefan Gehn
 |
 |  Authors:  Bill Nalen     bill@nalens.com
 |            Stefan Gehn    stefan+gkrellm@srcbox.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -275,7 +275,7 @@ gint		gkrellm_get_chartconfig_grid_resolution(GkrellmChartconfig *a)
     return (*(callbacks->gkrellm_get_chartconfig_grid_resolution))(a);
 }
 void		gkrellm_chartconfig_grid_resolution_connect(
-						GkrellmChartconfig *a, void (*fn)(), gpointer b)
+						GkrellmChartconfig *a, void (*fn)(GkrellmChartconfig *, gpointer), gpointer b)
 {
     (*(callbacks->gkrellm_chartconfig_grid_resolution_connect))(a, fn, b);
 }
@@ -601,9 +601,9 @@ void		gkrellm_set_in_button_callback(GkrellmDecalbutton *a,
 {
     (*(callbacks->gkrellm_set_in_button_callback))(a, func, data);
 }
-gboolean	gkrellm_in_button(GkrellmDecalbutton *button, GdkEventButton *a)
+gboolean	gkrellm_in_button(GkrellmDecalbutton *button, GdkEventButton *a, gpointer data)
 {
-    return (*(callbacks->gkrellm_in_button))(button, a);
+    return (*(callbacks->gkrellm_in_button))(button, a, data);
 }
 gboolean	gkrellm_in_decal(GkrellmDecal *a, GdkEventButton *b)
 {
@@ -1408,17 +1408,19 @@ GkrellmAlertPlugin	*gkrellm_alert_plugin_add(GkrellmMonitor *mon,
 }
 void		gkrellm_alert_plugin_alert_connect(GkrellmAlertPlugin *gap,
             		void (*alarm_func)(), void (*warn_func)(),
-					void (*update_func)(), void (*check_func)(),
+					void (*update_func)(), void (*check_func)(GkrellmAlert* alert, gpointer data, gfloat value),
 					void (*destroy_func)())
 {
     (*(callbacks->gkrellm_alert_plugin_alert_connect))(gap, alarm_func, warn_func, update_func, check_func, destroy_func);
 }
 void		gkrellm_alert_plugin_config_connect(GkrellmAlertPlugin *gap,
-					gchar *tab_name,
-            		void (*config_create_func)(), void (*config_done_func),
-            		void (*config_save_func)(),void (*config_load_func)())
+						gchar *tab_name,
+						void (*config_create_func)(),
+						void (*config_apply_func)(),
+						void (*config_save_func)(),
+						void (*config_load_func)())
 {
-    (*(callbacks->gkrellm_alert_plugin_config_connect))(gap, tab_name, config_create_func, config_done_func, config_save_func, config_load_func);
+    (*(callbacks->gkrellm_alert_plugin_config_connect))(gap, tab_name, config_create_func, config_apply_func, config_save_func, config_load_func);
 }
 gchar		*gkrellm_alert_plugin_config_get_id_string(GkrellmAlert *alert)
 {
