@@ -1,10 +1,10 @@
  /* GKrellM Windows Portion
 |  Copyright (C) 2002 Bill Nalen
-|                2007-2019 Stefan Gehn
+|                2007-2024 Stefan Gehn
 |
 |  Authors:  Bill Nalen     bill@nalens.com
 |            Stefan Gehn    stefan+gkrellm@srcbox.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -107,7 +107,7 @@ typedef struct
 						    gint);
     gint		(*gkrellm_get_chartconfig_grid_resolution)(GkrellmChartconfig *);
     void		(*gkrellm_chartconfig_grid_resolution_connect)(
-						    GkrellmChartconfig *, void (*fn)(), gpointer);
+						    GkrellmChartconfig *, void (*fn)(GkrellmChartconfig *, gpointer), gpointer);
     void		(*gkrellm_set_chartconfig_flags)(GkrellmChartconfig *, gint);
 
     void		(*gkrellm_chartconfig_grid_resolution_label)(
@@ -217,7 +217,7 @@ typedef struct
     GkrellmDecalbutton *(*gkrellm_decal_is_button)(GkrellmDecal *);
     void        (*gkrellm_set_in_button_callback)(GkrellmDecalbutton *,
                             gint (*func)(), gpointer data);
-    gboolean	(*gkrellm_in_button)(GkrellmDecalbutton *button, GdkEventButton *);
+    gboolean	(*gkrellm_in_button)(GkrellmDecalbutton *button, GdkEventButton *, gpointer data);
     gboolean	(*gkrellm_in_decal)(GkrellmDecal *, GdkEventButton *);
     void		(*gkrellm_decal_button_connect)(GkrellmDecalbutton *, void (*func)(),
 						    void *);
@@ -501,12 +501,14 @@ typedef struct
 						gchar *name);
 	void		(*gkrellm_alert_plugin_alert_connect)(GkrellmAlertPlugin *gap,
             			void (*alarm_func)(), void (*warn_func)(),
-						void (*update_func)(), void (*check_func)(),
+						void (*update_func)(), void (*check_func)(GkrellmAlert* alert, gpointer data, gfloat value),
 						void (*destroy_func)());
 	void		(*gkrellm_alert_plugin_config_connect)(GkrellmAlertPlugin *gap,
 						gchar *tab_name,
-            			void (*config_create_func)(), void (*config_done_func),
-            			void (*config_save_func)(),void (*config_load_func)());
+						void (*config_create_func)(),
+						void (*config_apply_func)(),
+						void (*config_save_func)(),
+						void (*config_load_func)());
 	gchar		*(*gkrellm_alert_plugin_config_get_id_string)(GkrellmAlert *alert);
 	void		(*gkrellm_alert_plugin_alert_attach)(GkrellmAlertPlugin *gap,
             			GkrellmAlert *alert, gpointer data);
